import { RdbmsConnection, SessionStorage } from '@shopify/shopify-app-session-storage';
import { IBaseProtocol } from 'pg-promise';
import { Session } from '@shopify/shopify-api';

declare abstract class BasePostgresConnection implements RdbmsConnection {
    sessionStorageIdentifier: string;
    protected ready: Promise<void>;
    constructor(sessionTableName?: string);
    abstract connect(): Promise<void>;
    abstract disconnect(): Promise<void>;
    abstract query(query: string, params: any[]): Promise<any[]>;
    hasTable(tablename: string): Promise<boolean>;
    getArgumentPlaceholder(position: number): string;
}

declare class NativePostgresConnection extends BasePostgresConnection {
    static withCredentials(host: string, dbName: string, username: string, password: string, sessionTableName: string): NativePostgresConnection;
    private pool;
    private dbUrl;
    constructor(dbUrl: string, sessionTableName?: string);
    query(query: string, params?: any[]): Promise<any[]>;
    disconnect(): Promise<void>;
    connect(): Promise<void>;
    getDatabase(): string | undefined;
    private init;
}

declare class PgPromiseConnection extends BasePostgresConnection {
    private db;
    constructor(pgPromise: IBaseProtocol<any>, sessionTableName?: string);
    query(query: string, params?: any[]): Promise<any[]>;
    connect(): Promise<void>;
    disconnect(): Promise<void>;
}

declare class AdaptablePostgresStorage implements SessionStorage {
    readonly ready: Promise<void>;
    private client;
    constructor(dbConnection: BasePostgresConnection);
    storeSession(session: Session): Promise<boolean>;
    loadSession(id: string): Promise<Session | undefined>;
    deleteSession(id: string): Promise<boolean>;
    deleteSessions(ids: string[]): Promise<boolean>;
    findSessionsByShop(shop: string): Promise<Session[]>;
    disconnect(): Promise<void>;
    private connectClient;
    private databaseRowToSession;
}

export { AdaptablePostgresStorage, BasePostgresConnection, NativePostgresConnection, PgPromiseConnection };
